@@ -1,8 +1,11 @@
 import typing
+
 import graphene
 
 GrapheneObjectType = typing.Union[
-    graphene.ObjectType, graphene.InputObjectType, graphene.Interface,
+    graphene.ObjectType,
+    graphene.InputObjectType,
+    graphene.Interface,
 ]
 
 GrapheneField = typing.TypeVar("graphene.BaseType")
